function [cct,Duv,offset,output,ill] = fitIll(spd,type)
    %fits measured illuminant SPD to Standard Illuminant of TYPE 'D' for
    %Daylight or 'P' for Blackbody/Incendescent in the wavelength range wl,
    %normalized to 1 at 560nm (if wl changes so should the 560nm indexes).
    
    if nargin < 2
        type = 'D'; end
    wl = 400:730;
    
    if strcmpi(type,'d')
        %load Sn distributions from Bruce Lindbloom excel spreadsheet. See:
        %http://brucelindbloom.com/Eqn_DIlluminant.html
        S = xlsread('E:\My Drive\Camera\Data\Illuminant\DIlluminants.xls','B3:E56');
        ill = zeros(size(S(:,2)));              %to be able to export it
        s0 = [0.3375 0.3519 0];                 %seed 5300K [xd yd offset]
        
        [xyo,~,~,output] = lsqnonlin(@lsD,s0);  %least square difference
        [cct,Duv] = cctDuv([xyo(1) xyo(2) 1-xyo(1)-xyo(2)]);
        offset = xyo(3);
    else
        ill = zeros(1,length(wl));
        c = 299792458;                          %m/s, speed of light in air
        h = 6.62607015e-34;                     %J/Hz, Plank's constant
        k = 1.380649e-23;                       %J.K, Boltzmann's
        %c1 = 2*pi*h*c^2;                       %redundant because normalized
        c2 = h*c/k;                             %ohno used 0.014388 m.K
        lambda = wl*1e-9;                       %m
        s0 = [5300 0];                          %seed cct and offset
        
        [To,~,~,output] = lsqnonlin(@lsP,s0);   %least square difference
        cct = To(1);
        Duv = [];                               %calculate it from ill
        offset = To(2);
    end
    
    plot(wl,spd,wl,ill); grid
    xlabel('nm'); ylabel('Relative Energy')
    legend('Measured',[type num2str(round(cct))])
    
    function se = lsP(s0)
        %computes difference of measured vs blackbody spectrum
        ill = lambda.^-5./(exp(c2./lambda/s0(1))-1) + s0(2);%c1 dropped because normalized below
        ill = ill / ill(161);                   %normalize to 1 at 560nm
        se = ill - spd;
        
    end
        
    function se = lsD(s0)
        %computes difference of measured vs standard D spectrum
        m = 0.0241 + 0.2562*s0(1) - 0.7341*s0(2);
        m1 = (-1.3515 - 1.7703*s0(1) + 5.9114*s0(2)) / m;
        m2 = (0.0300 - 31.4424*s0(1) +30.0717*s0(2)) / m;
        
        ill = S(:,2) + m1*S(:,3) + m2*S(:,4);
        ill = ill' / ill(27);                   %normalize to 1 at 560nm
        ill = interp1(300:10:830,ill,wl) + s0(3);
        
        se = ill - spd;
    end
end

